# Script: cortana_disable.sh
# Description: # Script para desactivar el alias 'cortana' para Claude Code
# Created:  2025/03/19 11:57:08
# Modified: 2025/03/11 12:00:00
# [Author] Mauro Rosero P. <mauro@rosero.one>
#
# Derechos de Autor (C) [2025] [Mauro Rosero P. <mauro@rosero.one>]
#
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

# Script para desactivar el alias 'cortana' para Claude Code
# Uso:
#   ./cortana_disable.sh
# Nota: no usa console.lib, ni console.es

# Configuración inicial
# Usar DEVELOPER_DIR de base.lib
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
BIN_BASE="bin"
BIN_LIBS="lib"
BIN_MESG="msg"
BIN_CFGS="config"

# Leer DEVSPATH desde el archivo de configuración o usar "devs" por defecto
if [ -f "$SCRIPT_DIR/config/devspath.dat" ]; then
  DEVSPATH=$(cat "$SCRIPT_DIR/$BIN_CFGS/devspath.dat")
else
  DEVSPATH="devs"
fi

BIN_HOME="$HOME/$DEVSPATH"
VERSION=$(cat "$BIN_HOME/$BIN_BASE/$BIN_CFGS/version")

# CHECK SHELL LANGUAGE
BIN_LANG=${LANG:0:2}

# Importar bibliotecas necesarias
source "${BIN_HOME}/${BIN_BASE}/${BIN_LIBS}/base.lib"

# Cargar mensajes en el idioma del sistema o español por defecto
load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "head"
title="${head_000} ${head_002}"

# Verificar que 'dialog' esté instalado
if ! command -v dialog &>/dev/null; then
  echo "${npm_001}"
  exit 1
fi

# Confirmar desactivación
dialog --backtitle "${title}" --title "${npm_031}" --yesno "${npm_048}" 7 50
if [[ $? -eq 0 ]]; then
  # Crear un archivo fuente para la desactivación del alias
  UNALIAS_FILE="$BIN_HOME/bin/cortana_unalias.sh"
  echo '#!/bin/bash' > "$UNALIAS_FILE"
  echo 'unalias cortana 2>/dev/null' >> "$UNALIAS_FILE"
  echo "echo \"${npm_049}\"" >> "$UNALIAS_FILE"
  chmod +x "$UNALIAS_FILE"
  
  # Ejecutar la función remove_cortana_alias del biblioteca base.lib para el archivo de configuración permanente
  remove_cortana_alias
  
  # Crear un mensaje con instrucciones para desactivar el alias en la sesión actual
  dialog --backtitle "${title}" --title "${npm_041}" --msgbox "${npm_042}\n\n${npm_050}\n\nsource $UNALIAS_FILE\n\n" 10 70
else
  dialog --backtitle "${title}" --title "${head_canceled}" --msgbox "${npm_008}" 6 40
  exit 1
fi

# Limpiar consola
clear
